﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.WebPages;
using System.Collections.Specialized;

namespace DynamicControlsCreation
{

    public class MobileDisplayMode : DefaultDisplayMode
    {
        private readonly StringCollection _useragenStringPartialIdentifiers = new StringCollection
    {
        "Android",
        "Mobile",
        "Opera Mobi",
        "Samsung",
        "HTC",
        "Nokia",
        "Ericsson",
        "SonyEricsson",
        "iPhone"
    };

        public MobileDisplayMode()
            : base("Mobile")
        {
            ContextCondition = (context => IsMobile(context.GetOverriddenUserAgent()));
        }

        private bool IsMobile(string useragentString)
        {
            return _useragenStringPartialIdentifiers.Cast<string>()
                        .Any(val => useragentString.IndexOf(val, StringComparison.InvariantCultureIgnoreCase) >= 0);
        }
    }
    /// <summary>
    /// Device specific startup configuration
    /// </summary>
    public static class DeviceConfig
    {
        const string DeviceTypePhone = "Phone";               
        const string DeviceTypeTablet = "Tablet";
        /// <summary>
        /// Evaluates incoming request and determines device.
        /// Adds an entry into the Display mode table
        /// </summary>
        public static void EvaluateDisplayMode()
        {
           // DisplayModeProvider.Instance.Modes.Insert(0, new MobileDisplayMode());
            

            DisplayModeProvider.Instance.Modes.Insert(0,
                new DefaultDisplayMode(DeviceTypePhone)
                {  //modify file (view that is served)
                    
                    //Query condition
                    ContextCondition = (ctx => (

                        //look at user agent
                        (ctx.GetOverriddenUserAgent() != null) &&

                        (//...either iPhone or iPad
                        
                            (ctx.GetOverriddenUserAgent().IndexOf("iPhone", StringComparison.OrdinalIgnoreCase) >= 0) ||
                            ((ctx.GetOverriddenUserAgent().IndexOf("Android", StringComparison.OrdinalIgnoreCase) >= 0) && (ctx.GetOverriddenUserAgent().IndexOf("Mobile", StringComparison.OrdinalIgnoreCase) >= 0)) ||
                            (ctx.GetOverriddenUserAgent().IndexOf("HTC", StringComparison.OrdinalIgnoreCase) >= 0) ||
                            (ctx.GetOverriddenUserAgent().IndexOf("Samsung", StringComparison.OrdinalIgnoreCase) >= 0) ||
                             (ctx.GetOverriddenUserAgent().IndexOf("Opera Mobi", StringComparison.OrdinalIgnoreCase) >= 0) ||
                              (ctx.GetOverriddenUserAgent().IndexOf("Mobile", StringComparison.OrdinalIgnoreCase) >= 0) ||
                               (ctx.GetOverriddenUserAgent().IndexOf("blackberry", StringComparison.OrdinalIgnoreCase) >= 0) ||
                                (ctx.GetOverriddenUserAgent().IndexOf("smartphone", StringComparison.OrdinalIgnoreCase) >= 0) ||
                                 (ctx.GetOverriddenUserAgent().IndexOf("iemobile", StringComparison.OrdinalIgnoreCase) >= 0) ||
                                  (ctx.GetOverriddenUserAgent().IndexOf("windows\\sce", StringComparison.OrdinalIgnoreCase) >= 0) ||
                            (ctx.GetOverriddenUserAgent().IndexOf("iPod", StringComparison.OrdinalIgnoreCase) >= 0)
                        )
                ))
                });

            DisplayModeProvider.Instance.Modes.Insert(0,
                new DefaultDisplayMode(DeviceTypeTablet)
                {
                    ContextCondition = (ctx => (

                        (ctx.GetOverriddenUserAgent() != null) &&

                        (
                            (ctx.GetOverriddenUserAgent().IndexOf("iPad", StringComparison.OrdinalIgnoreCase) >= 0) ||
                             (ctx.GetOverriddenUserAgent().IndexOf("tablet", StringComparison.OrdinalIgnoreCase) >= 0) ||
                              (ctx.GetOverriddenUserAgent().IndexOf("kindle", StringComparison.OrdinalIgnoreCase) >= 0) ||
                             (ctx.GetOverriddenUserAgent().IndexOf("xoom", StringComparison.OrdinalIgnoreCase) >= 0) ||
                              (ctx.GetOverriddenUserAgent().IndexOf("iPad", StringComparison.OrdinalIgnoreCase) >= 0) ||
                              ((ctx.GetOverriddenUserAgent().IndexOf("Android 4.0", StringComparison.OrdinalIgnoreCase) >= 0) && !(ctx.GetOverriddenUserAgent().IndexOf("Mobile", StringComparison.OrdinalIgnoreCase) >= 0)) ||
                            ((ctx.GetOverriddenUserAgent().IndexOf("Android", StringComparison.OrdinalIgnoreCase) >= 0) && !(ctx.GetOverriddenUserAgent().IndexOf("Mobile", StringComparison.OrdinalIgnoreCase) >= 0)) ||
                            (ctx.GetOverriddenUserAgent().IndexOf("Playbook", StringComparison.OrdinalIgnoreCase) >= 0)
                        )

                ))
                });
        }
    }
}