﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using DynamicControlsCreation.ViewModels;
using System.Xml.Linq;
using System.Data;
using System.Data.SqlClient;
using System.Configuration;
namespace DynamicControlsCreation.Models
{
  public class ControlsContext
  {
    private static Dictionary<string, DefaultControlsViewModel> _dynamicViewModel;

    public Dictionary<string, DefaultControlsViewModel> DynamicViewModel
    {
      get
      {
        return _dynamicViewModel;
      }
    }

    static ControlsContext()
    {      
      Init();
     
    }

    private static void Init()
    {
      _dynamicViewModel = new Dictionary<string, DefaultControlsViewModel>();
      XDocument doc = GetXmlDocument();
      CreateDynamicViewModel(doc);
    }

    private static void CreateDynamicViewModel(XDocument doc)
    {
      var viewNodes = from node in doc.Document.Descendants()
                      where node.Name == "view"
                      select node;

      foreach (var element in viewNodes)
      {
        AddControlType(element);
      }
    }

    private static void AddControlType(XElement element)
    {
      var controlTypes = from node in element.Descendants()
                         where node.Name == "type"
                         select node;

      DefaultControlsViewModel viewModel = new DefaultControlsViewModel();
      foreach (var type in controlTypes)
      {
        var id = (from idNode in type.Descendants("property")
                  where idNode.Attribute("name").Value == "ID"
                  select idNode.Attribute("value").Value).FirstOrDefault();

        var value = (from valueNode in type.Descendants("property")
                     where valueNode.Attribute("name").Value == "Value"
                     select valueNode.Attribute("value").Value).FirstOrDefault();

        var label = (from valueNode in type.Descendants("property")
                     where valueNode.Attribute("name").Value == "Label"
                     select valueNode.Attribute("value").Value).FirstOrDefault();

        var query = (from valueNode in type.Descendants("property")
                     where valueNode.Attribute("name").Value == "Query"
                     select valueNode.Attribute("value").Value).FirstOrDefault();

        var row = (from valueNode in type.Descendants("property")
                   where valueNode.Attribute("name").Value == "RowNumber"
                   select valueNode.Attribute("value").Value).FirstOrDefault();

        var obj = Activator.CreateInstance("DynamicControlsCreation", "DynamicControlsCreation.ViewModels." + type.FirstAttribute.Value + "ViewModel").Unwrap();
        var control = (ControlViewModel)obj;
        control.ID = id;
        control.Name = id;
        control.Label = label;
        control.Query = query;
        if (row != null)
        {
            control.RowNumber = Convert.ToInt32(row);
        }
        else
        {
            control.RowNumber = 1;
        }
        control.GetType().GetProperty("Value").SetValue(control, value, null);
        viewModel.Controls.Add(control);
      }
      _dynamicViewModel.Add(element.FirstAttribute.Value, viewModel);
    }

   
   
    private static XDocument GetXmlDocument()
    {
      string path = HttpContext.Current.Server.MapPath("~/App_Data/Controls.xml");
      XDocument doc = XDocument.Load(path);
      return doc;
    }
  }
}